==> piwigo-11.5.0.zip: piwigo/language/uk_UA/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Admin configuration'] = 'Конфігурація адміністратора';
$lang['also given by your host provider'] = 'також дізнайтесь у Вашого хостинг-провайдера';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Альтернативним рішенням є копіювання тексту в поле вище і вставте його в файл "local/config/database.inc.php" (Попередження: database.inc.php повинен містити тільки те, що в текстовому полі, без зворотної лінії або пропусків)';
$lang['Basic configuration'] = 'Базова конфігурація';
$lang['Can\'t connect to server'] = 'Не вдається підключитися до сервера';
$lang['Congratulations, Piwigo installation is completed'] = 'Вітаємо, Piwigo завершив встановлення';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'З\'єднання з сервером успішно, але з\'єднання з базою даних неможлива';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Створення файлу конфігурації local/config/database.inc.php не вдалося.';
$lang['Database configuration'] = 'Конфігурація бази даних';
$lang['Database name'] = 'Ім\'я бази даних';
$lang['Database table prefix'] = 'Префікс таблиць бази даних';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'таблиці бази даних імена, яких будуть починатися з префіксами (дозволяє управляти таблицями краще)';
$lang['Default gallery language'] = 'Типова мова галереї';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Не соромтеся проконсультуватися на форумі першим з будь-яким питанням: %s';
$lang['Download the config file'] = 'Завантажити файл конфігурації';
$lang['enter a login for webmaster'] = 'введіть лоґін веб-майстра';
$lang['Hope to see you back soon.'] = 'Сподіваюся побачити вас найближчим часом.';
$lang['Host'] = 'Хост';
$lang['Installation'] = 'Встановлення';
$lang['It appears your webhost is currently running PHP %s.'] = 'Схоже, ваш хостинг в даний час працює з PHP %s.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Він буде показаний відвідувачам. Це необхідно для адміністрації сайту';
$lang['Just another Piwigo gallery'] = 'Ще одна галерея Piwigo';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Тримайте його конфіденційність, він дозволяє отримати доступ до адміністративної панелі';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Потрібна допомога? Задайте питання на <a href="%s">форумі Piwigo</a>.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Зверніть увагу, ви можете змінити свою конфігурацію і перезавантажити собі Piwigo після цього.';
$lang['Password [confirm]'] = 'Пароль [підтвердження]';
$lang['PHP 5 is required'] = 'Потрібен PHP 5.2';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo можуть спробувати перемкнути конфігурацію PHP 5.2 шляхом створення або зміни .htaccess файлу.';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo не зміг налаштувати PHP 5.2';
$lang['please enter your password again'] = 'введіть пароль ще раз';
$lang['Sorry!'] = 'Вибачте!';
$lang['Start Install'] = 'Початок встановлення';
$lang['Try to configure PHP 5'] = 'Спробуйте налаштувати PHP 5.2';
$lang['user login given by your host provider'] = 'лоґін користувача дізнайтесь у вашого хостинг-провайдера';
$lang['user password given by your host provider'] = 'лоґін користувача дізнайтесь у Вашого хостинг-провайдера';
$lang['verification'] = 'перевірка';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Відвідувачі зможуть використовувати цю пошту, щоб зв\'язатися з адміністратором сайту';
$lang['webmaster login can\'t contain characters \' or "'] = 'лоґін веб-майстера не може містити символів \' або "';
$lang['Welcome to my photo gallery'] = 'Ласкаво просимо в фотогалерею';
$lang['Welcome to your new installation of Piwigo!'] = 'Ласкаво просимо у ваш новий встановлений Piwigo!';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Ви можете завантажити конфігураційний файл і завантажити його до local/config каталогу встановлення.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Ви повинні звернутися в службу підтримки вашого хостинг-провайдера і подивитися, як ви можете переключитися на PHP 5.2 самостійно.';
$lang['User'] = 'Користувач';
$lang['localhost or other, supplied by your host provider'] = 'локальний хост або будь-який інший, наданий вашим провайдером';

==> piwigo-16.0.0.zip: piwigo/language/uk_UA/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Admin configuration'] = 'Конфігурація адміністратора';
$lang['also given by your host provider'] = 'також дізнайтесь у Вашого хостинг-провайдера';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Альтернативним рішенням є копіювання тексту в поле вище і вставте його в файл "local/config/database.inc.php" (Попередження: database.inc.php повинен містити тільки те, що в текстовому полі, без зворотної лінії або пропусків)';
$lang['Basic configuration'] = 'Базова конфігурація';
$lang['Can\'t connect to server'] = 'Не вдається підключитися до сервера';
$lang['Congratulations, Piwigo installation is completed'] = 'Вітаємо, Piwigo завершив встановлення';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'З\'єднання з сервером успішно, але з\'єднання з базою даних неможлива';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Створення файлу конфігурації local/config/database.inc.php не вдалося.';
$lang['Database configuration'] = 'Конфігурація бази даних';
$lang['Database name'] = 'Ім\'я бази даних';
$lang['Database table prefix'] = 'Префікс таблиць бази даних';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'таблиці бази даних імена, яких будуть починатися з префіксами (дозволяє управляти таблицями краще)';
$lang['Default gallery language'] = 'Типова мова галереї';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Не соромтеся проконсультуватися на форумі першим з будь-яким питанням: %s';
$lang['Download the config file'] = 'Завантажити файл конфігурації';
$lang['enter a login for webmaster'] = 'введіть лоґін веб-майстра';
$lang['Hope to see you back soon.'] = 'Сподіваюся побачити вас найближчим часом.';
$lang['Host'] = 'Хост';
$lang['Installation'] = 'Встановлення';
$lang['It appears your webhost is currently running PHP %s.'] = 'Схоже, ваш хостинг в даний час працює з PHP %s.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Він буде показаний відвідувачам. Це необхідно для адміністрації сайту';
$lang['Just another Piwigo gallery'] = 'Ще одна галерея Piwigo';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Тримайте його конфіденційність, він дозволяє отримати доступ до адміністративної панелі';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Потрібна допомога? Задайте питання на <a href="%s">форумі Piwigo</a>.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Зверніть увагу, ви можете змінити свою конфігурацію і перезавантажити собі Piwigo після цього.';
$lang['Password [confirm]'] = 'Пароль [підтвердження]';
$lang['PHP 5 is required'] = 'Потрібен PHP 5.2';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo можуть спробувати перемкнути конфігурацію PHP 5.2 шляхом створення або зміни .htaccess файлу.';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo не зміг налаштувати PHP 5.2';
$lang['please enter your password again'] = 'введіть пароль ще раз';
$lang['Sorry!'] = 'Вибачте!';
$lang['Start Install'] = 'Початок встановлення';
$lang['Try to configure PHP 5'] = 'Спробуйте налаштувати PHP 5.2';
$lang['user login given by your host provider'] = 'лоґін користувача дізнайтесь у вашого хостинг-провайдера';
$lang['user password given by your host provider'] = 'лоґін користувача дізнайтесь у Вашого хостинг-провайдера';
$lang['verification'] = 'перевірка';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Відвідувачі зможуть використовувати цю пошту, щоб зв\'язатися з адміністратором сайту';
$lang['webmaster login can\'t contain characters \' or "'] = 'лоґін веб-майстера не може містити символів \' або "';
$lang['Welcome to my photo gallery'] = 'Ласкаво просимо в фотогалерею';
$lang['Welcome to your new installation of Piwigo!'] = 'Ласкаво просимо у ваш новий встановлений Piwigo!';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Ви можете завантажити конфігураційний файл і завантажити його до local/config каталогу встановлення.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Ви повинні звернутися в службу підтримки вашого хостинг-провайдера і подивитися, як ви можете переключитися на PHP 5.2 самостійно.';
$lang['User'] = 'Користувач';
$lang['localhost or other, supplied by your host provider'] = 'локальний хост або будь-який інший, наданий вашим провайдером';
$lang['PHP version %s required (you are running on PHP %s)'] = 'потрібно мати PHP версії %s (ви використовуєте PHP %s)';
